@@ -1,6 +1,6 @@
 package HTML::Accessors;
 
-# @(#)$Id: Accessors.pm 22 2008-05-16 15:43:51Z pjf $
+# @(#)$Id: Accessors.pm 23 2008-05-23 20:12:24Z pjf $
 
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ use HTML::Tagset;
 use NEXT;
 use Readonly;
 
-use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 22 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 23 $ =~ /\d+/gmx );
 
 Readonly my $ATTRS => { content_type   => q(application/xhtml+xml) };
 Readonly my $INP   => { button         => q(button),
@@ -187,7 +187,7 @@ HTML::Accessors - Generate HTML elements
 
 =head1 Version
 
-0.1.$Rev: 22 $
+0.1.$Rev: 23 $
 
 =head1 Synopsis
 
@@ -208,11 +208,9 @@ over STDIN.
 
 The returned tags are either XHTML 1.1 or HTML 4.01 compliant.
 
-=head1 Subroutines/Methods
+=head1 Configuration and Environment
 
-=head2 new
-
-The constructor defines one attribute:
+The constructor defines accessors and mutators for one attribute:
 
 =over 3
 
@@ -224,6 +222,12 @@ generate HTML compatible tags instead
 
 =back
 
+=head1 Subroutines/Methods
+
+=head2 new
+
+Uses C<_arg_list> to process the passed options
+
 =head2 escape_html
 
 Expose C<HTML::GenerateUtil::escape_html>
@@ -391,10 +395,6 @@ Call C<Carp::croak>. Don't load L<Carp> if we don't have to
 
 Simplistic merging of two hashes
 
-=head1 Configuration and Environment
-
-None
-
 =head1 Diagnostics
 
 C<Carp::carp> is called to issue a warning about undefined elements
